#
#   SCOREM
#
"""
data
----------

Data for the `scoremipsum` module.
"""
TEAMS_DEFAULT = ("Advancers Battlers Clashers Destroyers "
                 "Engineers Fighters Guardians Harriers").split()

TEAMS_MLB_AL_EAST = "Yankees Orioles Red_Sox Rays Blue_Jays".split()
TEAMS_MLB_AL_CENTRAL = "".split()
TEAMS_MLB_AL_WEST = "".split()
TEAMS_MLB_NL_EAST = "".split()
TEAMS_MLB_NL_CENTRAL = "".split()
TEAMS_MLB_NL_WEST = "".split()

TEAMS_NBA_EASTERN_A = "Knicks Magic 76ers Nets Hornets".split()
TEAMS_NBA_EASTERN_B = "".split()
TEAMS_NBA_WESTERN_C = "".split()
TEAMS_NBA_WESTERN_A = "".split()
TEAMS_NBA_WESTERN_B = "".split()
TEAMS_NBA_WESTERN_C = "".split()

TEAMS_NFL_AFC_EAST = "Patriots Bills Dolphins Jets".split()
TEAMS_NFL_AFC_NORTH = "Ravens Steelers Browns Bengals".split()
TEAMS_NFL_AFC_SOUTH = "Texans Titans Colts Jaguars".split()
TEAMS_NFL_AFC_WEST = "Chiefs Raiders Broncos Chargers".split()

TEAMS_NFL_NFC_EAST = "Eagles Cowboys Giants Redskins".split()
TEAMS_NFL_NFC_NORTH = "Packers Vikings Bears Lions".split()
TEAMS_NFL_NFC_SOUTH = "Saints Falcons Buccaneers Panthers".split()
TEAMS_NFL_NFC_WEST = "49ers Seahawks Rams Cardinals".split()

TEAMS_NHL_EASTERN_ATLANTIC =\
    "Panthers Maple_Leafs Lightning Senators Red_Wings Bruins Canadiens Sabres".split()
TEAMS_NHL_EASTERN_METRO =\
    "Capitals Hurricanes Devils Blue_Jackets Rangers Islanders Flyers Penguins".split()
TEAMS_NHL_WESTERN_CENTRAL =\
    "Jets Stars Wild Avalanche Hockey_Club Blues Predators Blackhawks".split()
TEAMS_NHL_WESTERN_PACIFIC =\
    "Golden_Knights Oilers Kings Canucks Flames Ducks Kraken Sharks".split()

#   Copyright information below
#   ---
#   MLB team names are registered trademarks
#   of Major League Baseball and respective teams.
#   ---
#   NBA team names are registered trademarks
#   of the National Basketball Association and respective teams.
#   ---
#   NFL team names are registered trademarks
#   of the National Football League and respective teams.
#   ---
#   NHL team names are registered trademarks
#   of the National Hockey League and respective teams.
#   ---
#   Names of existing teams used for demonstration purposes only
#   and may not be used for any other purpose without appropriate permissions.
#   ---
